@@ -1,14 +1,16 @@
 use core::marker::PhantomData;
-use core::mem::{self, ManuallyDrop};
+use core::mem::ManuallyDrop;
 use ffi::{self, CPtr, types::AlignedType};
 use ffi::types::{c_uint, c_void};
 use Error;
 use Secp256k1;
 
 #[cfg(any(feature = "std", feature = "alloc"))]
+#[cfg_attr(docsrs, doc(cfg(any(feature = "std", feature = "alloc"))))]
 pub use self::alloc_only::*;
 
 #[cfg(feature = "global-context-less-secure")]
+#[cfg_attr(docsrs, doc(cfg(feature = "global-context-less-secure")))]
 /// Module implementing a singleton pattern for a global `Secp256k1` context
 pub mod global {
     #[cfg(feature = "global-context")]
@@ -94,6 +96,7 @@ mod private {
 }
 
 #[cfg(any(feature = "std", feature = "alloc"))]
+#[cfg_attr(docsrs, doc(cfg(any(feature = "std", feature = "alloc"))))]
 mod alloc_only {
     #[cfg(feature = "std")]
     use std::alloc;
@@ -105,15 +108,18 @@ mod alloc_only {
     impl private::Sealed for VerifyOnly {}
 
     use super::*;
-    const ALIGN_TO: usize = mem::align_of::<AlignedType>();
+    const ALIGN_TO: usize = ::core::mem::align_of::<AlignedType>();
 
     /// Represents the set of capabilities needed for signing.
+    #[cfg_attr(docsrs, doc(cfg(any(feature = "std", feature = "alloc"))))]
     pub enum SignOnly {}
 
     /// Represents the set of capabilities needed for verification.
+    #[cfg_attr(docsrs, doc(cfg(any(feature = "std", feature = "alloc"))))]
     pub enum VerifyOnly {}
 
     /// Represents the set of all capabilities.
+    #[cfg_attr(docsrs, doc(cfg(any(feature = "std", feature = "alloc"))))]
     pub enum All {}
 
     impl Signing for SignOnly {}
